#!/bin/sh
# -------------------------------------------------------------------------
# (C) Copyright Marxmeier Software AG 2008-2014
#
# Eloquence JDLG Plugin Interface
#
# Function: Create self-signed JAR certificate.
#
# Note: DON'T USE. Recent Java versions block self-signed JARs.
# -------------------------------------------------------------------------

# Configuration
# -------------

# Edit the values below as necessary.
#
# Notes:
# - TITLE and ORGANIZATION must follow X.500 Distinguished Names syntax.
#   Comma should be avoided or must be backslash-escaped.
# - ALIAS must follow file naming conventions. Avoid spaces and special
#   characters.
# - TITLE should match desc.title in build.xml.
# - ALIAS should match plugin.filename in build.xml.
# - ORGANIZATION should match desc.organization in build.xml.

TITLE="Eloquence JDLG Plugin"
ALIAS="jdlg-plugin"
ORGANIZATION="Marxmeier Software AG"
COUNTRY="DE"
DAYS_VALID=365

# Commands
KEYTOOL="keytool"

# -----------------
# End Configuration

if [ -n "$1" ]; then
  if [ "$1" = "-help" -o $# -ne 1 ]; then
    echo "usage: $0 [ALIAS]"
    exit 3
  fi
  ALIAS="$1"
fi

DNAME="C=$COUNTRY,O=$ORGANIZATION,CN=$TITLE"
KEYSTORE="keystore.bin"
PASSWORDS_CONF="passwords.cnf"

cd "`dirname $0`"

if [ ! -r "$PASSWORDS_CONF" ]; then
  echo "Password configuration file not found."
  exit 2
fi
. "./$PASSWORDS_CONF"
if [ -z "$KEYSTORE_PASS" -o -z "$KEY_PASS" ]; then
  echo "KEYSTORE_PASS or KEY_PASS not configured."
  exit 2
fi

rm -f "$KEYSTORE"

"$KEYTOOL" -genkeypair \
  -alias "$ALIAS" \
  -dname "$DNAME" \
  -validity "$DAYS_VALID" \
  -keyalg RSA \
  -keysize 2048 \
  -keystore "$KEYSTORE" \
  -storepass "$KEYSTORE_PASS" \
  -keypass "$KEY_PASS" \
|| exit 1

"$KEYTOOL" -exportcert \
  -alias "$ALIAS" \
  -keystore "$KEYSTORE" \
  -storepass "$KEYSTORE_PASS" \
  -keypass "$KEY_PASS" \
  -file "$ALIAS.selfsigned.cert.bin" \
|| exit 1

"$KEYTOOL" -printcert \
  -file "$ALIAS.selfsigned.cert.bin" \
|| exit 1

rm "$ALIAS.selfsigned.cert.bin"

echo
echo "Self-signed JAR certificate for $ALIAS successfully created in $KEYSTORE."
echo
